#!/bin/sh

###############################################################################
# Licensed Materials - Property of Tivoli Systems
# 5697-ENV
# (C) COPYRIGHT Tivoli Systems, an IBM Company 1997, 2005
# All rights reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################
#
# Start the Tivoli Topology console on:
#
# - Tivoli Desktop
#   * supported platforms
#
# - Non-Tivoli Desktop
#   * supported Unix platforms
#   * Windows NT with Tivoli Framework (i.e. "bash" is available)
#
# Command Line Arguments:
# =======================
# $1 - required; fully qualified installation path specification
#                  example:  NT:   C:\Tivoli\bin\generic_unix\TDS\client
#                            Unix: /usr/local/Tivoli/bin/generic_unix/TDS/client
#                  could be: NT:   %bindir%\..\generic_unix\TDS\client
#                            Unix: $BINDIR/../generic_unix/TDS/client
# $2 - optional; additional console command line argument
# ...
# $n - optional; additional console command line argument
#
# Assumptions
# ===========
# TCONSOLE_CLASSPATH - optional; Java code library(s) placed at end
#                                of CLASSPATH
# TCONSOLE_JAVAOPTS  _ optional; command line arg(s) for Java
# TCONSOLE_BACKDOOR  - optional; Java code library(s) placed at front
#                                of CLASSPATH
# WRUNUI             - optional; command used to start Java if called from
#                                TME desktop running on Windows NT
#
#
# CHANGE HISTORY:
#
# 08/08/2000   For AIX, use jre subdir and direct path invocation and  JED
#              also disable JIT for AIX only for now...(explanations below)
###############################################################################

###############################################################################
# The installation "root" must be specified
###############################################################################
if [ -z "$1" ]; then
  echo "Usage: $0 installation path [ args ]"
  exit 1
fi

###############################################################################
# Isolate command line args
###############################################################################
IPATH=$1                     # install path

shift

ARGS="$*"                    # the rest are console args

###############################################################################
# Create JAVA_LIB and JAVA_CMD environment variable accourding to INTERP
# NOTE: JRE or JDK must be installed into $IPATH/../../../[INTERP]/TDS/java
###############################################################################
JAVA_CMD=""
BINDIR=""

###  AIX script logic changed for Java 2 JRE 1.3.0:
###  IJAVA must be hardcoded to find libjvm.a and
###  java subdirectory path must be /TDS/jre not /TDS/java
###  since java JVM needs absolute /jre for /jre/bin and
###  /jre/lib otherwise it cannot open dlopen javalib.a
###  (jim dramis 8/1/2000)

if [ -d $IPATH/../../../w32-ix86/TDS/java ] ; then
{
        IJAVA="$IPATH\..\..\..\w32-ix86\TDS\java"
        PATH="$IJAVA\bin;$PATH"
        export PATH
        JAVA_CMD="$IJAVA\bin\java"
        BINDIR="$IPATH/../../../w32-ix86"
        export BINDIR
}
elif [ -d $IPATH/../../../solaris2/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../solaris2/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        BINDIR="$IPATH/../../../solaris2"
        export BINDIR
}
elif [ -d $IPATH/../../../linux-ix86/TDS/java ] ; then
{
        IJAVA="$IPATH/../../../linux-ix86/TDS/java"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        BINDIR="$IPATH/../../../linux-ix86"
        export BINDIR
}
elif [ -d $IPATH/../../../linux-x64/TDS/jre ] ; then
{
        IJAVA="$IPATH/../../../linux-x64/TDS/jre"
        PATH="$IJAVA/bin:$PATH"
        export PATH
        JAVA_CMD="$IJAVA/bin/java"
        BINDIR="$IPATH/../../../linux-x64"
        export BINDIR
}
else
   echo 'Error: Unable to determine integrated JRE.'
        ls -d $IPATH/../../../
   exit 1
fi

###############################################################################
# Determine if running on Unix or Windows NT
#
# On Windows NT, the CLASSPATH variable must use Intel-style backslashes
# instead of forward slashes for directory name separators, and semicolons for
# path element separators.
###############################################################################
J_RUN_PGM=""

if [ -n "$windir" ] ; then

   # convert any Unix directory separators to Windows equivalent before
   # creating composite items

   IPATH=`echo $IPATH | tr '/' '\\\'`

     LIB="$IPATH\\lib"

  FLGUPD="$LIB\\FilesUpdated"

  CP_UPD="$LIB\\ihsupd.jar;$JAVA_LIB"
  CP_RUN="$TCONSOLE_BACKDOOR;$LIB\\ihseuc.jar;$IPATH\\..\\ibmflb\\jars\\tivflb14.jar;TCONSOLE_CLASSPATH"

  JAVA_OPTS="-mx256M -ms16M $TCONSOLE_JAVAOPTS"

  ############################################################################
  # Check for special TME Desktop invocation program
  ############################################################################
  J_RUN_PGM="$WRUNUI"
else

     LIB="$IPATH/lib"

  FLGUPD="$LIB/FilesUpdated"

  CP_UPD="$LIB/ihsupd.jar"
  CP_RUN="$TCONSOLE_BACKDOOR:$LIB/ihseuc.jar:$IPATH/../ibmflb/jars/tivflb14.jar:$TCONSOLE_CLASSPATH"

  #######################################################################
  # Use -oss option with with unix platforms
  #######################################################################
  JAVA_OPTS="-mx256M -ms16M -oss1M $TCONSOLE_JAVAOPTS"
    
  JAVA_OPTS="$JAVA_OPTS -DTCONSOLE_BACKDOOR=$TCONSOLE_BACKDOOR"
  JAVA_OPTS="$JAVA_OPTS -DTCONSOLE_CLASSPATH=$TCONSOLE_CLASSPATH"
  JAVA_OPTS="$JAVA_OPTS -DTCONSOLE_JAVAOPTS=$TCONSOLE_JAVAOPTS"
  JAVA_OPTS="$JAVA_OPTS -DTCONSOLE_DISPLAY=$DISPLAY"


  ############################################################################
  # On Unix systems, we must be sure that the display is exported
  # or else the console won't start...
  #
  # if XHOST fails, abort now to avoid "hanging" below when java started
  ############################################################################
  if [ ! "xhost +" ]
  then
    echo "Unable to start this console due to XHOST failure!"
    echo "Current PATH: $PATH"
    exit 1
  else
    if [ -n "$WD_DISPLAY" ]
    then
       DISPLAY="$WD_DISPLAY"
       export DISPLAY
    fi
  fi
fi

J_UPD="$JAVA_CMD $JAVA_OPTS -classpath $CP_UPD com.tivoli.ihs.update.IhsUpdate"
J_RUN="$J_RUN_PGM $JAVA_CMD $JAVA_OPTS -classpath $CP_RUN com.tivoli.ihs.client.IhsClient $ARGS"

###############################################################################
# Loop until the console exits without any updates to apply
###############################################################################
TRYAGAIN="yes"

while [ -n "$TRYAGAIN" ]
do
   TRYAGAIN=""

   ############################################################################
   # Updates to apply?
   ############################################################################
   if [ -f $FLGUPD ]; then

     echo $J_UPD
          $J_UPD
   fi

   ############################################################################
   # If it appears that there's still updates to apply, then some sort
   # of error occurred during update processing
   ############################################################################
   if [ -f $FLGUPD ]; then
     exit 1
   fi

   ############################################################################
   # Start the console
   ############################################################################
   echo $J_RUN
        $J_RUN

   errorlevel=$?

   ############################################################################
   # Restart the console if the client needs to resynchronize
   ############################################################################
   if [ $errorlevel = 254 ]; then
       echo $J_RUN
       $J_RUN
   fi

   ############################################################################
   # Updates to apply?
   ############################################################################
   if [ -f $FLGUPD ]; then
     TRYAGAIN="yes"
   fi
done

###############################################################################
# Check the file permissions
###############################################################################
if [ -z "$windir" ] ; then
  $IPATH/bin/installTConsolePerm.sh
fi

exit 0
